﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Runtime.InteropServices;
using System.Windows.Interop;
using PeteBrown.ScreenCapture.Win32Api;

namespace PeteBrown.ScreenCapture
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void CaptureRegionButton_Click(object sender, RoutedEventArgs e)
        {
            CapturedImage.Source = ScreenCapture.CaptureRegion(100, 100, 500, 500, true);
        }

        private void CaptureScreenButton_Click(object sender, RoutedEventArgs e)
        {
            CapturedImage.Source = ScreenCapture.CaptureFullScreen(true);
        }

        private void CaptureWindowWithBackgroundButton_Click(object sender, RoutedEventArgs e)
        {
            PickWindowWithMouse();
        }

        private void PickWindowWithMouse()
        {
            Window captureWindow = new Window();

            captureWindow.WindowStyle = WindowStyle.None;
            captureWindow.Title = string.Empty;
            captureWindow.ShowInTaskbar = false;
            captureWindow.AllowsTransparency = true;
            captureWindow.Background = new SolidColorBrush(Color.FromArgb(0x01, 0x00, 0x00, 0x00));
            captureWindow.Topmost = true;

            captureWindow.Left = SystemParameters.VirtualScreenLeft;
            captureWindow.Top = SystemParameters.VirtualScreenTop;
            captureWindow.Width = SystemParameters.VirtualScreenWidth;
            captureWindow.Height = SystemParameters.VirtualScreenHeight;

            Point mouseDown = new Point();

            captureWindow.KeyUp += (s, e) =>
                {
                    if (e.Key == Key.Escape)
                    {
                        // cancel the capture
                        captureWindow.Close();
                        this.Show();
                    }
                };

            captureWindow.MouseDown += (s, e) =>
                {
                    mouseDown = e.GetPosition(captureWindow);
                };

            captureWindow.MouseUp += (s, e) =>
                {
                    Point current = e.GetPosition(captureWindow);

                    if (Math.Abs(mouseDown.X - current.X) < 10.0 &&
                        Math.Abs(mouseDown.Y - current.Y) < 10.0)
                    {
                        // this is the window they want 

                        Point screenCoords = captureWindow.PointToScreen(current);
                        captureWindow.Close();

                        IntPtr hWnd = User32.WindowFromPoint(new Win32Point((int)screenCoords.X, (int)screenCoords.Y));
                        User32.SetForegroundWindow(hWnd);

                        //CapturedImage.Source = ScreenCapture.CaptureWindow(hWnd, true, Colors.White, true);
                        CapturedImage.Source = ScreenCapture.CaptureWindow(hWnd, false, Colors.Transparent, true);

                        // show our app window again, and bring it to the foreground
                        WindowInteropHelper helper = new WindowInteropHelper(this);
                        this.Show();
                        User32.SetForegroundWindow(helper.Handle);
                        
                    }
                };

            this.Hide();
            captureWindow.Show();

        }

    }
}
